# Teledetection

<p align="center">
<img src="doc/logo.png" width="320px">
<br>
<a href="https://forgemia.inra.fr/cdos-pub/teledetection/-/releases">
<img src="https://forgemia.inra.fr/cdos-pub/teledetection/-/badges/release.svg">
</a>
<a href="https://forgemia.inra.fr/cdos-pub/teledetection/-/commits/main">
<img src="https://forgemia.inra.fr/cdos-pub/teledetection/badges/main/pipeline.svg">
</a>
<a href="LICENSE">
<img src="https://img.shields.io/badge/License-Apache%202.0-blue.svg">
</a>
<a href="https://forgemia.inra.fr/cdos-pub/teledetection/-/commits/main">
<img src="https://forgemia.inra.fr/cdos-pub/teledetection/badges/main/coverage.svg">

</p>

**teledetection** enables to use the STAC based geospatial data infrastructure 
of *la Maison de la Teledetection*.

For more information read the [documentation](https://cdos-pub.pages.mia.inra.fr/teledetection).

## Contact

remi cresson @ inrae
pablo boizeau @ ird
